@@ -1,9 +1,13 @@
-splinebins <- function(bEdges, bCounts, m=NULL, numIterations=16, monoMethod=c("hyman", "monoH.FC"), ipn=200) {
+splinebins <- function(bEdges, bCounts, m=NULL, numIterations=16, monoMethod=c("hyman", "monoH.FC")) {
   monoMethod <- match.arg(monoMethod)
   L <- length(bCounts)
+  if(!(is.na(bEdges[L]) | is.infinite(bEdges[L])))
+    warning("Top bin is bounded. Expect inaccurate results.\n")
   tot <- sum(bCounts)
-  if(is.null(m))  # no mean provided, so make one up
+  if(is.null(m)) { # no mean provided, so make one up
+    warning("No mean provided: expect inaccurate results.\n")
     m <- sum(0.5*(c(bEdges[1:(L-1)],2.0*bEdges[L-1])+c(0, bEdges[1:(L-1)]))*bCounts/tot)
+  } 
   sumbAreas <- vapply(1:L, function(i) {sum(bCounts[1:i])/tot}, numeric(1))
   tailEnd <- 1.05*bEdges[L-1] # start with a really short tail
   x <- c(0, bEdges[1:(L-1)], tailEnd, tailEnd*1.01)
@@ -43,7 +47,7 @@ splinebins <- function(bEdges, bCounts, m=NULL, numIterations=16, monoMethod=c("
         l <- tailEnd
     }
   }
-  xfix <- seq(0, tailEnd, length.out = ipn) # ADDED in v0.2.0: sample CDF to invert
+  xfix <- seq(0, tailEnd, length.out = 200) # ADDED in v0.2.0: sample CDF to invert
   yfix <- f(xfix)
   finv <- splinefun(yfix, xfix, method=monoMethod) # ADDED in v0.2.0: approximate inverse CDF
   splineCDF <- function(x){
@@ -55,5 +59,16 @@ splinebins <- function(bEdges, bCounts, m=NULL, numIterations=16, monoMethod=c("
   splineInvCDF <- function(x){ # ADDED in v0.2.0: approximate inverse CDF
     ifelse(x<0, 0, ifelse(x>1, tailEnd, finv(x)))
   }
-  return(list(splinePDF=splinePDF, splineCDF=splineCDF, E=tailEnd, est_mean=est_mean, shrinkFactor=shrinkFactor, splineInvCDF=splineInvCDF))
+  median_bin <- which(cumsum(bCounts) > sum(bCounts)/2)[1]
+  med_fit <- splineInvCDF(0.5)
+  fitWarn <- (med_fit < bEdges[median_bin-1]) | (med_fit > bEdges[median_bin])
+  if(fitWarn)
+    warning("Inaccurate fit detected. Proceed with caution.\n")
+  return(list(splinePDF=splinePDF, 
+              splineCDF=splineCDF, 
+              E=tailEnd, 
+              est_mean=est_mean, 
+              shrinkFactor=shrinkFactor, 
+              splineInvCDF=splineInvCDF,
+              fitWarn=fitWarn))
 }
